from setuptools import setup, find_packages

VERSION = '0.0.1'
DESCRIPTION = 'Pacote em python'
LONG_DESCRIPTION = 'Pacote de calculos'

#setting up
setup(
        #'name' deve corresponder ao nome da pasta 'PacoteTeste'
        name = "CalculosPacotes",
        version=VERSION,
        author="Millena Lira",
        author_email="millena.mp2@gmail.com",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        license='MIT',
        packages=find_packages(),
        install_requires=[],# adicione outros pacotes que precisem ser instalados com o seu pacote. EX: 'caer'
        
) 
    


class CalculoMat:
    
    def __init__(self,num1,num2):
        self.num1 = num1
        self.num2 = num2
        
    def soma(self):
        return self.num1 + self.num2

    def subtrair(self):
        return self.num1 - self.num2
    
    def multiplica(self):
        return self.num1 * self.num2

    def dividir(self):
        if self.num2 != 0:
            return self.num1 / self.num2
        else:
            raise ValueError("Não é possível dividir por zero.")